==> mongodb-7.0.23.gh.tar.gz: mongo-r7.0.23/src/mongo/unittest/stringify.cpp <==
/**
 *    Copyright (C) 2021-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/unittest/matcher_core.h"

#include <cstdlib>
#include <string>
#include <typeinfo>

#include <fmt/format.h>

#include "mongo/util/assert_util.h"
#include "mongo/util/hex.h"

namespace mongo::unittest::stringify {

std::string formatTypedObj(const std::type_info& ti, StringData s) {
    return format(FMT_STRING("[{}={}]"), demangleName(ti), s);
}

std::string lastResortFormat(const std::type_info& ti, const void* p, size_t sz) {
    return formatTypedObj(ti, hexdump(p, sz));
}

}  // namespace mongo::unittest::stringify

==> mongodb-8.0.8.gh.tar.gz: mongo-r8.0.8/src/mongo/unittest/stringify.cpp <==
/**
 *    Copyright (C) 2021-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include <fmt/format.h>
#include <string>
#include <typeinfo>

#include "mongo/base/string_data.h"
#include "mongo/unittest/stringify.h"
#include "mongo/util/assert_util.h"
#include "mongo/util/hex.h"

namespace mongo::unittest::stringify {

std::string formatTypedObj(const std::type_info& ti, StringData s) {
    return format(FMT_STRING("[{}={}]"), demangleName(ti), s);
}

std::string lastResortFormat(const std::type_info& ti, const void* p, size_t sz) {
    return formatTypedObj(ti, hexdump(p, sz));
}

}  // namespace mongo::unittest::stringify
